---
title: <span class="badge object-type-scalar"></span> SievertPerHour
---
# <span class="badge object-type-scalar"></span> SievertPerHour

Radiation: Sievert/hour (Sv/h)

## Definition

```python
# Radiation: Sievert/hour (Sv/h)
SievertPerHour: typing.Literal["radsvh"] = "radsvh"
```
